@@ -101,6 +101,10 @@ class Requestant(httping.Parsent):
             if connection and "keep-alive" in connection.lower():
                 self.persisted = True
 
+        if self.persisted:  # override timeout so server never timesout
+            self.incomer.timeout =  0.0  # never timesout
+
+
     def parseHead(self):
         """
         Generator to parse headers in heading of .msg
@@ -146,7 +150,6 @@ class Requestant(httping.Parsent):
         self.hostname = pathSplits.hostname
         self.port = pathSplits.port
         self.query = pathSplits.query  # WSGI spec leaves it quoted do not unquote
-        #self.query = httping.unquoteQuery(pathSplits.query)  # unquote only the values
         self.fragment = pathSplits.fragment
 
         leaderParser = httping.parseLeader(raw=self.msg,
@@ -316,6 +319,9 @@ class Responder(object):
         """
         Close any resources
         """
+        if not self.closed and not self.ended:
+            self.write(b'')  # in case chunked send empty chunk to terminate
+        self.ended = True
         self.closed = True
 
     def reset(self, environ, chunkable=None):
@@ -646,8 +652,18 @@ class Valet(object):
 
     def close(self):
         """
-        Call .servant.closeAll()
+        Close all reqs, reps, and ixes
+
         """
+        # start with reqs
+        for ca in list(self.reqs.keys()):  # need list as closeConnection deletes
+            self.closeConnection(ca)
+
+        # just in case there is an orphan rep
+        for ca in list(self.reps.keys()):  # need list as closeConnection deletes
+            self.closeConnection(ca)
+
+        # just in case there is an orphan ix
         self.servant.closeAll()
 
 
@@ -711,13 +727,15 @@ class Valet(object):
         """
         Close and remove connection given by ca
         """
-        self.servant.removeIx(ca)
         if ca in self.reqs:
             self.reqs[ca].close()  # this signals request parser
             del self.reqs[ca]
         if ca in self.reps:
             self.reps[ca].close()  # this signals response handler
+            if ca in self.servant.ixes:
+                self.servant.ixes[ca].serviceTxes()  #  send final bytes to socket
             del self.reps[ca]
+        self.servant.removeIx(ca)
 
     def serviceConnects(self):
         """
@@ -782,15 +800,15 @@ class Valet(object):
         """
         Service pending responders
         """
-        for ca, respondent in self.reps.items():
-            if respondent.closed:
+        for ca, responder in self.reps.items():
+            if responder.closed:
                 self.closeConnection(ca)
                 continue
 
-            if not respondent.ended:
-                respondent.service()
+            if not responder.ended:
+                responder.service()
 
-            if respondent.ended:
+            if responder.ended:
                 requestant = self.reqs[ca]
                 if requestant.persisted:
                     if requestant.parser is None:  # reuse
